from app import app, db
from app.forms import LoginForm, YearForm, IntervalForm
from app.models import User, Annual_Data, Glacier
from flask import flash, redirect, render_template, url_for, request
from flask_login import current_user, login_user, logout_user, login_required
from werkzeug.urls import url_parse
from processing.tabulate import create_table
from database.queries import query_annual_data, query_user


@app.route("/")
@app.route("/index")
def index():
    return render_template("index.html", title="Home Page")


@app.route("/login", methods=["GET", "POST"])
def login():
    if current_user.is_authenticated:
        return redirect(url_for("admin"))
    form = LoginForm()
    if form.validate_on_submit():
        user = query_user(form)
        if user is None or not user.check_password(form.password.data):
            flash("Invalid username or password")
            return redirect(url_for("login"))
        login_user(user, remember=form.remember_me.data)
        next_page = request.args.get("next")
        if not next_page or url_parse(next_page).netloc != "":
            next_page = url_for("admin")
        return redirect(next_page)
    return render_template("login.html", title="Sign In", form=form)


@app.route("/logout")
def logout():
    logout_user()
    return redirect(url_for("index"))


@app.route("/admin")
@login_required
def admin():
    return render_template("admin.html", title="Admin Page")


@app.route("/nuke")
@login_required
def nuke():
    return render_template("nuked.html", title="NUKE THE SYSTEM!")


@app.route("/data")
def data():
    return render_template("data.html", title="Data")


@app.route("/table_selection", methods=["GET", "POST"])
def table_selection():
    form = YearForm()
    if form.validate_on_submit():
        query = query_annual_data(form)
        if query.scalar() is None:
            flash("Sorry, no results found")
            return redirect(url_for("table_selection"))
        table = create_table(query.statement)
        return render_template("table.html", table=table, title="Table")
    return render_template("table_selection.html", title="Data", form=form)


@app.route("/table")
def table():
    return render_template("table.html", table=table, title="Table")


@app.route("/plots")
def plots():
    return render_template("data.html", title="Data")
